@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.2201';
+our $VERSION = '0.2202';
 
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
@@ -112,7 +112,7 @@ sub counter_strategy
     my $opponent = $player == 1 ? 2 : 1;
 
     my @keys = 1 .. keys %{ $self->{$player} };
-    my @pure = ( 1, (0) x ( keys( %{ $self->{$player} } ) - 1 ) );
+    my @pure = ( 1, (0) x ( @keys - 1 ) );
 
     my $i = permutations( \@pure );
     while ( my $x = $i->next )
@@ -497,7 +497,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2201
+version 0.2202
 
 =head1 SYNOPSIS
 
@@ -573,6 +573,7 @@ and T > R > P > S is:
 And in this implementation that would be:
 
  $g = Game::Theory::TwoPersonMatrix->new(
+    %strategies,
     payoff1 => [ [ -1, -3 ], [  0, -2 ] ],  # Blue: [ R1, S1 ], [ T1, P1 ]
     payoff2 => [ [ -1,  0 ], [ -3, -2 ] ],  # Red:  [ R2, T2 ], [ S2, P2 ]
  );
@@ -580,17 +581,17 @@ And in this implementation that would be:
 Where the two player strategies are to either Cooperate (1) or Defect (2).  This
 is given by a hash for each of the two players, where the values are Boolean:
 
- %strategy = (
+ %strategies = (
     1 => { 1 => $cooporate1, 2 => $defect1 }, # Blue
     2 => { 1 => $cooporate2, 2 => $defect2 }, # Red
  );
 
-See the F<eg/play> program in this distribution for an example that exercises
+See the F<eg/> programs in this distribution for examples that exercise
 strategic variations of the prisoner's dilemma.
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
  $g = Game::Theory::TwoPersonMatrix->new(
     1 => { 1 => 0.5, 2 => 0.5 },
@@ -614,13 +615,13 @@ Payoffs are given by array references of lists of outcomes.  For zero-sum games
 this is a single payoff list.  For non-zero-sum games this is given as two lists
 - one for each player.
 
-=head2 expected_payoff()
+=head2 expected_payoff
 
  $x = $g->expected_payoff();
 
 Return the expected payoff value of a game.
 
-=head2 s_expected_payoff()
+=head2 s_expected_payoff
 
  $g = Game::Theory::TwoPersonMatrix->new(
     1 => { 1 => '(1 - p)', 2 => 'p' },
@@ -634,14 +635,14 @@ Return the symbolic expected payoff expression for a non-numeric game.
 Using real payoff values, we solve the resulting expression for B<p> in the
 F<eg/> examples.
 
-=head2 counter_strategy()
+=head2 counter_strategy
 
  $x = $g->counter_strategy($player);
 
 Return the expected payoff, for a given player, of either a zero-sum or
 non-zero-sum game, given pure opponent strategies.
 
-=head2 saddlepoint()
+=head2 saddlepoint
 
  $x = $g->saddlepoint;
 
@@ -649,40 +650,40 @@ Return the saddlepoint of a zero-sum game, or C<undef> if there is none.
 
 A saddlepoint is simultaneously minimum for its row and maximum for its column.
 
-=head2 oddments()
+=head2 oddments
 
  $x = $g->oddments();
 
 Return each player's "oddments" for a 2x2 zero-sum game with no saddlepoint.
 
-=head2 row_reduce()
+=head2 row_reduce
 
  $g->row_reduce();
 
 Reduce a zero-sum game by identifying and eliminating strictly dominated rows
 and their associated player strategies.
 
-=head2 col_reduce()
+=head2 col_reduce
 
  $g->col_reduce();
 
 Reduce a zero-sum game by identifying and eliminating strictly dominated columns
 and their associated opponent strategies.
 
-=head2 mm_tally()
+=head2 mm_tally
 
  $x = $g->mm_tally();
 
 For zero-sum games, return the maximum of row minimums and the minimum of column
 maximums.  For non-zero-sum games, return the maximum of row and column minimums.
 
-=head2 pareto_optimal()
+=head2 pareto_optimal
 
  $x = $g->pareto_optimal();
 
 Return the Pareto optimal outcomes for a non-zero-sum game.
 
-=head2 nash()
+=head2 nash
 
  $x = $g->nash();
 
@@ -691,7 +692,7 @@ Identify the Nash equilibria in a non-zero-sum game.
 Given payoff pair C<(a,b)>, B<a> is maximum for its column and B<b> is maximum
 for its row.
 
-=head2 play()
+=head2 play
 
  $x = $g->play();
  $x = $g->play(%strategies);
